#ifndef POKEPLATINUM_UNK_0202B37C_H
#define POKEPLATINUM_UNK_0202B37C_H

#include "strbuf.h"
#include "struct_decls/struct_0202B4A0_decl.h"
#include "struct_defs/struct_0202B510.h"
#include "struct_decls/struct_021C0794_decl.h"

int sub_0202B37C(void);
void sub_0202B384(UnkStruct_0202B4A0 * param0, int param1, int param2);
void sub_0202B3A8(UnkStruct_0202B4A0 * param0);
void sub_0202B3D8(UnkStruct_0202B4A0 * param0, u32 param1);
u32  sub_0202B400(UnkStruct_0202B4A0 * param0, int param1);
void sub_0202B40C(UnkStruct_0202B4A0 * param0, int param1, u32 param2);
u32  sub_0202B428(UnkStruct_0202B4A0 * param0);
const u16 * sub_0202B42C(const UnkStruct_0202B4A0 * param0, int param1, int param2);
void  sub_0202B444(UnkStruct_0202B4A0 * param0, int param1, int param2, Strbuf *param3);
void sub_0202B470(UnkStruct_0202B4A0 * param0, int param1, int param2);
int sub_0202B47C(const UnkStruct_0202B4A0 * param0, int param1);
int sub_0202B488(const UnkStruct_0202B4A0 * param0, int param1);
void sub_0202B494(UnkStruct_0202B4A0 * param0, int param1, int param2);
UnkStruct_0202B4A0 * sub_0202B4A0(UnkStruct_021C0794 * param0);
BOOL sub_0202B4AC(const UnkStruct_0202B4A0 * param0, int param1);
BOOL sub_0202B4C4(const UnkStruct_0202B4A0 * param0, int param1);
BOOL sub_0202B4D8(const UnkStruct_0202B4A0 * param0, const u16 * param1);
BOOL sub_0202B510(const UnkStruct_0202B510 * param0);
BOOL sub_0202B530(const UnkStruct_0202B510 * param0, const UnkStruct_0202B510 * param1);

#endif // POKEPLATINUM_UNK_0202B37C_H
